FixedColumns examples - Integration

# FixedColumns example Integration

The examples in this section show FixedColumns being used with other DataTables extensions.

### Integration with other DataTables extensions

- Select - whole row
- Select - checkboxes
- DataTables API

Please refer to the DataTables documentation for full information about its API properties and methods.
Additionally, there are a wide range of extensions and plug-ins which extend the capabilities of DataTables.

DataTables designed and created by SpryMedia Ltd © 2007-2016
DataTables is licensed under the MIT license.